use std::env::current_dir;

use crate::cli::config::generate::ConfigGenerateArgs;
use crate::paths::berg_data_dir;
use crate::types::config::{BergConfig, ConfigLocation};

pub fn generate_config(args: ConfigGenerateArgs) -> anyhow::Result<()> {
    let path_dir = match args.location {
        ConfigLocation::Global => berg_data_dir()?,
        ConfigLocation::Local => current_dir()?,
    };
    let path_file = path_dir.join("berg.toml");
    if !path_file.exists() || (path_file.exists() && args.replace) {
        if args.replace {
            std::fs::remove_file(path_file.clone())?;
        }
        std::fs::create_dir_all(path_dir.clone())?;
        let config = BergConfig::default();
        let config_text = toml::to_string(&config)?;
        std::fs::write(path_file.clone(), config_text)?;
        println!("Successfully created berg config at {path_file:?}");
    } else {
        println!("berg config already exists at {path_file:?}!");
    }
    Ok(())
}
