use forgejo_api::structs::IssueListLabelsQuery;

use crate::actions::label::display_label;
use crate::cli::label::delete::DeleteLabelArgs;

use crate::git_info::repo_owner::RepoAndOwner;
use crate::render::spinner::spin_until_ready;
use crate::render::ui::multi_fuzzy_select_with_key;

use crate::actions::text_manipulation::select_prompt_for;
use crate::types::context::BergContext;

pub async fn delete_label(ctx: BergContext<DeleteLabelArgs>) -> anyhow::Result<()> {
    let RepoAndOwner { repo, owner } = ctx.repo_owner()?;
    let labels_list = spin_until_ready(ctx.client.issue_list_labels(
        owner.as_str(),
        repo.as_str(),
        IssueListLabelsQuery::default(),
    ))
    .await?;

    let selected_labels = multi_fuzzy_select_with_key(
        &labels_list,
        select_prompt_for("label"),
        |_| false,
        display_label,
    )?;

    for id in selected_labels.into_iter().filter_map(|label| label.id) {
        ctx.client
            .issue_delete_label(owner.as_str(), repo.as_str(), id)
            .await?;
    }

    Ok(())
}
