use forgejo_api::structs::{IssueListLabelsQuery, Label};

use crate::cli::label::list::ListLabelsArgs;

use crate::git_info::repo_owner::RepoAndOwner;
use crate::render::option::option_display;
use crate::render::spinner::spin_until_ready;

use crate::types::context::BergContext;

pub async fn list_label(ctx: BergContext<ListLabelsArgs>) -> anyhow::Result<()> {
    let RepoAndOwner { repo, owner } = ctx.repo_owner()?;
    let labels_list = spin_until_ready(ctx.client.issue_list_labels(
        owner.as_str(),
        repo.as_str(),
        IssueListLabelsQuery::default(),
    ))
    .await?;

    present_labels_list(&ctx, labels_list);

    Ok(())
}

fn present_labels_list(ctx: &BergContext<ListLabelsArgs>, labels: Vec<Label>) {
    let labels_empty = labels.is_empty();

    let mut table = ctx.make_table();

    table
        .set_header(vec![format!(
            "Labels{}",
            labels_empty.then_some(" (empty)").unwrap_or_default()
        )])
        .add_rows(
            labels
                .into_iter()
                .map(|label| vec![option_display(&label.name)]),
        );

    println!("{table}");
}
