use forgejo_api::structs::{IssueGetMilestonesListQuery, Milestone};

use crate::cli::milestone::list::ListMilestonesArgs;

use crate::git_info::repo_owner::RepoAndOwner;
use crate::render::option::option_display;
use crate::render::spinner::spin_until_ready;
use crate::types::context::BergContext;

pub async fn list_milestone(ctx: BergContext<ListMilestonesArgs>) -> anyhow::Result<()> {
    let RepoAndOwner { repo, owner } = ctx.repo_owner()?;
    let milestones_list = spin_until_ready(ctx.client.issue_get_milestones_list(
        owner.as_str(),
        repo.as_str(),
        IssueGetMilestonesListQuery::default(),
    ))
    .await?;

    present_milestones_list(&ctx, milestones_list);

    Ok(())
}

fn present_milestones_list(ctx: &BergContext<ListMilestonesArgs>, milestones: Vec<Milestone>) {
    let milestones_empty = milestones.is_empty();

    let mut table = ctx.make_table();

    table
        .set_header(vec![format!(
            "Milestones{}",
            milestones_empty.then_some(" (empty)").unwrap_or_default()
        )])
        .add_rows(
            milestones
                .into_iter()
                .map(|milestone| vec![option_display(&milestone.title)]),
        );

    println!("{table}");
}
