use forgejo_api::structs::{NotificationThread, NotifyGetListQuery};

use crate::cli::notification::list::ListNotificationArgs;

use crate::render::option::option_display;
use crate::types::context::BergContext;

pub async fn list_notifications(ctx: BergContext<ListNotificationArgs>) -> anyhow::Result<()> {
    let notification_threads_list = ctx
        .client
        .notify_get_list(NotifyGetListQuery {
            ..Default::default()
        })
        .await?;

    tracing::debug!("{notification_threads_list:?}");

    present_notification_threads(&ctx, notification_threads_list);

    Ok(())
}

fn present_notification_threads(
    ctx: &BergContext<ListNotificationArgs>,
    notification_threads_list: Vec<NotificationThread>,
) {
    let header = if notification_threads_list.is_empty() {
        "Notification Threads (empty)"
    } else {
        "Notification Threads"
    };

    let mut table = ctx.make_table();

    table
        .set_header(vec![header])
        .add_rows(
            notification_threads_list
                .into_iter()
                .map(|notification_thread| {
                    vec![option_display(
                        &notification_thread
                            .subject
                            .as_ref()
                            .and_then(|subject| subject.title.as_ref()),
                    )]
                }),
        );

    println!("{table}");
}
