use forgejo_api::structs::User;

use crate::cli::repo::assignees::RepoAssigneesArgs;
use crate::git_info::repo_owner::RepoAndOwner;
use crate::render::option::option_display;
use crate::render::spinner::spin_until_ready;
use crate::types::context::BergContext;

pub async fn assignees_repo(ctx: BergContext<RepoAssigneesArgs>) -> anyhow::Result<()> {
    let RepoAndOwner { repo, owner } = ctx.repo_owner()?;
    let repo_assignees =
        spin_until_ready(ctx.client.repo_get_assignees(owner.as_str(), repo.as_str())).await?;

    present_repo_assignees(&ctx, repo_assignees);

    Ok(())
}

fn present_repo_assignees(ctx: &BergContext<RepoAssigneesArgs>, repo_assignees: Vec<User>) {
    let mut table = ctx.make_table();

    table
        .set_header(vec![format!(
            "Repository Assignees{}",
            repo_assignees
                .is_empty()
                .then_some(" (empty)")
                .unwrap_or_default()
        )])
        .add_rows(
            repo_assignees
                .into_iter()
                .map(|assignee| vec![option_display(&assignee.login)]),
        );

    println!("{table}");
}
