pub mod api;
pub mod auth;
pub mod config;
pub mod issue;
pub mod label;
pub mod milestone;
pub mod notification;
pub mod pull_request;
pub mod repo;
pub mod user;

use clap::{CommandFactory, Parser};
use clap_complete::Shell;

#[derive(Debug, clap::Parser)]
#[command(version)]
pub struct BergCommand {
    #[command(subcommand)]
    pub sub: BergActions,

    #[arg(
        long,
        help = [
            "Whether or not to disable all interactive features.",
            "In this case arguments have to be provided in the console!",
            ""
        ].join("\n")
    )]
    pub non_interactive: bool,
}

impl BergCommand {
    pub fn generate_completion(shell: Shell) -> anyhow::Result<()> {
        clap_complete::generate(
            shell,
            &mut BergCommand::command(),
            "berg",
            &mut std::io::stdout(),
        );
        Ok(())
    }
}

/// Codeberg CLI app
#[derive(Parser, Debug)]
pub enum BergActions {
    #[command(subcommand)]
    API(api::ApiArgs),

    #[command(subcommand)]
    Auth(auth::AuthArgs),

    #[command(subcommand)]
    Config(config::ConfigArgs),

    #[command(subcommand)]
    User(user::UserArgs),

    #[command(subcommand)]
    Issue(issue::IssueArgs),

    #[command(subcommand)]
    Pull(pull_request::PullRequestArgs),

    #[command(subcommand)]
    Label(label::LabelArgs),

    #[command(subcommand)]
    Repo(repo::RepoArgs),

    #[command(subcommand)]
    Milestone(milestone::MilestoneArgs),

    #[command(subcommand)]
    Notification(notification::NotificationArgs),

    /// Print completion script
    Completion {
        /// Shell to generate completion for
        shell: Shell,
    },
}
